==> 0.6.1.tar.gz: lief/api/c/ELF/Section.cpp <==
/* Copyright 2017 R. Thomas
 * Copyright 2017 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "Section.hpp"

namespace LIEF {
namespace ELF {
void init_c_sections(Elf_Binary_t* c_binary, Binary* binary) {

  it_sections sections = binary->get_sections();

  c_binary->sections = static_cast<Elf_Section_t**>(
      malloc((sections.size() + 1) * sizeof(Elf_Section_t**)));

  for (size_t i = 0; i < sections.size(); ++i) {
    Section& b_section = sections[i];
    c_binary->sections[i] = static_cast<Elf_Section_t*>(malloc(sizeof(Elf_Section_t)));
    const std::vector<uint8_t>& section_content = b_section.content();
    uint8_t* content = static_cast<uint8_t*>(malloc(section_content.size() * sizeof(uint8_t)));
    std::copy(
        std::begin(section_content),
        std::end(section_content),
        content);

    c_binary->sections[i]->name            = b_section.name().c_str();
    c_binary->sections[i]->flags           = b_section.flags();
    c_binary->sections[i]->type            = static_cast<enum ::SECTION_TYPES>(b_section.type());
    c_binary->sections[i]->virtual_address = b_section.virtual_address();
    c_binary->sections[i]->offset          = b_section.file_offset();
    c_binary->sections[i]->original_size   = b_section.original_size();
    c_binary->sections[i]->link            = b_section.link();
    c_binary->sections[i]->info            = b_section.information();
    c_binary->sections[i]->alignment       = b_section.alignment();
    c_binary->sections[i]->entry_size      = b_section.entry_size();
    c_binary->sections[i]->content         = content;
    c_binary->sections[i]->size            = section_content.size();
    c_binary->sections[i]->entropy         = b_section.entropy();
  }
  c_binary->sections[sections.size()] = nullptr;

}



void destroy_sections(Elf_Binary_t* c_binary) {

  Elf_Section_t **sections = c_binary->sections;
  for (size_t idx = 0; sections[idx] != nullptr; ++idx) {
    free(sections[idx]->content);
    free(sections[idx]);
  }
  free(c_binary->sections);

}

}
}

==> 0.8.2.tar.gz: lief/api/c/ELF/Section.cpp <==
/* Copyright 2017 R. Thomas
 * Copyright 2017 Quarkslab
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
#include "Section.hpp"

namespace LIEF {
namespace ELF {
void init_c_sections(Elf_Binary_t* c_binary, Binary* binary) {

  it_sections sections = binary->sections();

  c_binary->sections = static_cast<Elf_Section_t**>(
      malloc((sections.size() + 1) * sizeof(Elf_Section_t**)));

  for (size_t i = 0; i < sections.size(); ++i) {
    Section& b_section = sections[i];
    c_binary->sections[i] = static_cast<Elf_Section_t*>(malloc(sizeof(Elf_Section_t)));
    const std::vector<uint8_t>& section_content = b_section.content();
    uint8_t* content = static_cast<uint8_t*>(malloc(section_content.size() * sizeof(uint8_t)));
    std::copy(
        std::begin(section_content),
        std::end(section_content),
        content);

    c_binary->sections[i]->name            = b_section.name().c_str();
    c_binary->sections[i]->flags           = b_section.flags();
    c_binary->sections[i]->type            = static_cast<enum ::ELF_SECTION_TYPES>(b_section.type());
    c_binary->sections[i]->virtual_address = b_section.virtual_address();
    c_binary->sections[i]->offset          = b_section.file_offset();
    c_binary->sections[i]->original_size   = b_section.original_size();
    c_binary->sections[i]->link            = b_section.link();
    c_binary->sections[i]->info            = b_section.information();
    c_binary->sections[i]->alignment       = b_section.alignment();
    c_binary->sections[i]->entry_size      = b_section.entry_size();
    c_binary->sections[i]->content         = content;
    c_binary->sections[i]->size            = section_content.size();
    c_binary->sections[i]->entropy         = b_section.entropy();
  }
  c_binary->sections[sections.size()] = nullptr;

}



void destroy_sections(Elf_Binary_t* c_binary) {

  Elf_Section_t **sections = c_binary->sections;
  for (size_t idx = 0; sections[idx] != nullptr; ++idx) {
    free(sections[idx]->content);
    free(sections[idx]);
  }
  free(c_binary->sections);

}

}
}
